[gtk+/gtk-style-context: 268/533] GtkWidgetPath: turn into a boxed type.



commit 3900fc9acd99e9f99d94a885dd8c6374c090e2aa
Author: Carlos Garnacho <carlosg gnome org>
Date:   Wed Oct 20 19:33:39 2010 +0200

    GtkWidgetPath: turn into a boxed type.

 gtk/gtkwidgetpath.c |    6 +++++-
 1 files changed, 5 insertions(+), 1 deletions(-)
---
diff --git a/gtk/gtkwidgetpath.c b/gtk/gtkwidgetpath.c
index 4b4e186..dfd2afe 100644
--- a/gtk/gtkwidgetpath.c
+++ b/gtk/gtkwidgetpath.c
@@ -30,7 +30,7 @@
  * @Title: GtkWidgetPath
  * @See_also: #GtkStyleContext
  *
  * #GtkWidgetPath is an struct that represents a widget hierarchy from
  * the topmost widget, typically a toplevel, to any child. This widget
  * path abstraction is used in #GtkStyleContext on behalf of the real
  * widget in order to query style information.
@@ -80,6 +80,10 @@
  * that applies to the described widget.
  **/
 
+G_DEFINE_BOXED_TYPE (GtkWidgetPath, gtk_widget_path,
+		     gtk_widget_path_copy, gtk_widget_path_free)
+
+
 typedef struct GtkPathElement GtkPathElement;
 
 struct GtkPathElement
@@ -30,7 +30,7 @@
  * @See_also: #GtkStyleContext
  *
- * #GtkWidgetPath is an struct that represents a widget hierarchy from
+ * #GtkWidgetPath is a boxed type that represents a widget hierarchy from
  * the topmost widget, typically a toplevel, to any child. This widget
  * path abstraction is used in #GtkStyleContext on behalf of the real



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]